@@ -1,6 +1,6 @@
 /*
  * XML LDAP client
- * $Id: xdap.h,v 1.7 2003/02/24 23:51:22 dsandras Exp $
+ * $Id: xdap.h,v 1.9 2004/02/09 19:14:35 dsandras Exp $
  * Copyright 2001 paul666@mailandnews.com
  * Licensed under version 2 or later of the GNU GPL
  */
@@ -109,6 +109,12 @@ void dumpres (LDAP *, LDAPMessage *);
 int parsefile (char *, xmlEntityPtr (*)(void *, const xmlChar *),
 	       xmlEntityPtr (**)(void *, const xmlChar *));
 
+#define XDAPLEAKCHECK 0 /* define this to show leaks of libxml node->_private */
+#define REGMAX 500 /* maximum no of slots to store malloced pointers */
+#define DEBUGXDAPLEAK 0 /* show allocs/frees */
+void xdapleakcheck(void);
+void xdapfree(void);
+
 G_END_DECLS
 
 #endif
