@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                         endpoint.h  -  description
  *                         --------------------------
  *   begin                : Sat Dec 23 2000
- *   copyright            : (C) 2000-2003 by Damien Sandras
+ *   copyright            : (C) 2000-2004 by Damien Sandras
  *   description          : This file contains the Endpoint class.
  *
  */
@@ -54,7 +54,7 @@
 
 class GMILSClient;
 class GMLid;
-
+class GMH323Gatekeeper;
 
 
 /**
@@ -177,7 +177,7 @@ class GMH323EndPoint : public H323EndPoint
 
 
   /* DESCRIPTION  :  This callback is called when a call is forwarded.
-   * BEHAVIOR     :  Outputs a message in the history and statusbar.
+   * BEHAVIOR     :  Outputs a message in the log and statusbar.
    * PRE          :  /
    */
   virtual BOOL OnConnectionForwarded (H323Connection &,
@@ -427,14 +427,15 @@ class GMH323EndPoint : public H323EndPoint
    * BEHAVIOR     :  Update the audio device volume (playing then recording). 
    * PRE          :  /
    */
-  BOOL SetDeviceVolume (unsigned int, unsigned int);
+  BOOL SetDeviceVolume (PSoundChannel *, BOOL, unsigned int);
 
   
   /* DESCRIPTION  :  /
    * BEHAVIOR     :  Returns the audio device volume (playing then recording). 
    * PRE          :  /
    */
-  BOOL GetDeviceVolume (unsigned int &, unsigned int &);
+  BOOL GetDeviceVolume (PSoundChannel *, BOOL, unsigned int &);
+  
 
 
   /* DESCRIPTION  :  /
@@ -536,7 +537,7 @@ class GMH323EndPoint : public H323EndPoint
    *                 audio device.
    * PRE          :  /
    */
-  BOOL DeviceVolume (BOOL, unsigned int &, unsigned int &);
+  BOOL DeviceVolume (PSoundChannel *, BOOL, BOOL, unsigned int &);
 
 
   /* DESCRIPTION  :  /
@@ -614,9 +615,6 @@ class GMH323EndPoint : public H323EndPoint
 
   CallingState calling_state; 
 
-  GDKVideoOutputDevice *transmitted_video_device; 
-  GDKVideoOutputDevice *received_video_device; 
-
   PTimer NoIncomingMediaTimer;
   PTimer ILSTimer;
   PTimer RTPTimer;
@@ -635,6 +633,7 @@ class GMH323EndPoint : public H323EndPoint
   /* The encoding video grabber */
   GMVideoGrabber *video_grabber;
 
+  GMH323Gatekeeper *gk;
   
   GMILSClient *ils_client;
   PThread *audio_tester;
@@ -653,6 +652,9 @@ class GMH323EndPoint : public H323EndPoint
 
   PMutex sound_event_mutex;
   
+  PMutex audio_channel_mutex;
+  PMutex video_channel_mutex;
+
 #ifdef HAS_IXJ
   GMLid *lid;
 #endif
