@@ -1,6 +1,6 @@
 
 /* GnomeMeeting -- A Video-Conferencing application
- * Copyright (C) 2000-2003 Damien Sandras
+ * Copyright (C) 2000-2004 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  *                         ldap_window.h  -  description
  *                         -----------------------------
  *   begin                : Wed Feb 28 2001
- *   copyright            : (C) 2000-2003 by Damien Sandras 
+ *   copyright            : (C) 2000-2004 by Damien Sandras 
  *   description          : This file contains functions to build the 
  *                          addressbook window.
  *
@@ -85,6 +85,12 @@ enum {
 
 
 /* The functions  */
+void gnomemeeting_addressbook_edit_contact_dialog (gchar *url);
+
+void gnomemeeting_addressbook_edit_contact_dialog (gchar *section,
+						   gchar *name,
+						   gchar *url,
+						   gchar *speeddial);
 
 /* DESCRIPTION  :  /
  * BEHAVIOR     :  Build the LDAP window and returns it.
@@ -175,10 +181,21 @@ gint contact_clicked_cb (GtkWidget *,
  *                 a row corresonding to an user.
  * BEHAVIOR     :  Add the user name in the combo box and call him or transfer
  *                 the call to that user.
- * PRE          :  data is the page type or 3 if contact activated from history
+ * PRE          :  data is the page type or 3 if contact activated from calls history
  */
 void contact_activated_cb (GtkTreeView *,
 			   GtkTreePath *,
 			   GtkTreeViewColumn *,
 			   gpointer);
+
+
+/* DESCRIPTION  :  /
+ * BEHAVIOR     :  Rename the contact section (group or server) given as
+ *                 parameter under its non-escaped form into the other
+ *                 parameter.
+ * PRE          :  Valid old contact section name, new contact section name.
+ */
+void rename_contact_section (const char *,
+                             const char *,
+                             gboolean);
 #endif
