@@ -93,9 +93,6 @@ void
 gnomemeeting_sound_daemons_suspend (void)
 {
 #ifndef WIN32
-#if defined(HAS_ESD)
-  return;
-#else
   int esd_client = 0;
   
   /* Put ESD into standby mode */
@@ -105,7 +102,6 @@ gnomemeeting_sound_daemons_suspend (void)
       
   esd_close (esd_client);
 #endif
-#endif
 }
 
 
@@ -113,9 +109,6 @@ void
 gnomemeeting_sound_daemons_resume (void)
 {
 #ifndef WIN32
-#if defined(HAS_ESD)
-  return;
-#else
   int esd_client = 0;
 
   /* Put ESD into normal mode */
@@ -125,7 +118,6 @@ gnomemeeting_sound_daemons_resume (void)
 
   esd_close (esd_client);
 #endif
-#endif
 }
 
 
@@ -580,7 +572,7 @@ void GMAudioTester::Main ()
   test_dialog =
     gtk_dialog_new_with_buttons ("Audio test running",
 				 GTK_WINDOW (gw->druid_window),
-				 (enum GtkDialogFlags) (GTK_DIALOG_MODAL),
+				 (GtkDialogFlags) (GTK_DIALOG_MODAL),
 				 GTK_STOCK_OK,
 				 GTK_RESPONSE_ACCEPT,
 				 NULL);
